pub mod plot;
pub mod bar;
pub mod pie;

const TITLE_SIZE: f32 = 37.;
const YLABEL_SIZE: f32 = 29.;
//const XLABEL_SIZE: f32 = 29.;
pub const FONT_SIZE: f32 = 24.; //27.
const COORD_THICKNESS: f32 = 2.;
const DISTANCE_X_AXIS: f32 = 70.;


